# verifiNN

This project intends to implement convex optimization based methods for verification of neural netrowks.

## References:
- https://scholarworks.calstate.edu/concern/theses/4t64gv41s (main)
- https://arxiv.org/pdf/1811.01057.pdf
- https://arxiv.org/pdf/1903.06758.pdf
- https://arxiv.org/pdf/1903.01287.pdf